Comment/annotate DatapathId class as immutable
diff --git a/java_gen/pre-written/src/main/java/org/projectfloodlight/openflow/types/DatapathId.java b/java_gen/pre-written/src/main/java/org/projectfloodlight/openflow/types/DatapathId.java
index f58d658..660ff7c 100644
--- a/java_gen/pre-written/src/main/java/org/projectfloodlight/openflow/types/DatapathId.java
+++ b/java_gen/pre-written/src/main/java/org/projectfloodlight/openflow/types/DatapathId.java
@@ -1,5 +1,6 @@
 package org.projectfloodlight.openflow.types;
 
+import org.projectfloodlight.openflow.annotations.Immutable;
 import org.projectfloodlight.openflow.util.HexString;
 
 import com.google.common.primitives.Longs;
@@ -7,10 +8,11 @@
 
 /**
  * Abstraction of a datapath ID that can be set and/or accessed as either a
  * long value or a colon-separated string.
  *
  * @author Rob Vaterlaus <rob.vaterlaus@bigswitch.com>
  */
+@Immutable
 public class DatapathId implements Comparable<DatapathId> {
 
     public static final DatapathId NONE = new DatapathId(0);
@@ -7,10 +8,11 @@
 /**
  * Abstraction of a datapath ID that can be set and/or accessed as either a
- * long value or a colon-separated string.
+ * long value or a colon-separated string. Immutable
  *
  * @author Rob Vaterlaus <rob.vaterlaus@bigswitch.com>